/*
  +----------------------------------------------------------------------+
  | Open Swoole                                                          |
  +----------------------------------------------------------------------+
  | This source file is subject to version 2.0 of the Apache license,    |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.apache.org/licenses/LICENSE-2.0.html                      |
  +----------------------------------------------------------------------+
*/

#ifndef SWOOLE_VERSION_H_
#define SWOOLE_VERSION_H_

#define SWOOLE_MAJOR_VERSION 4
#define SWOOLE_MINOR_VERSION 11
#define SWOOLE_RELEASE_VERSION 1
#define SWOOLE_EXTRA_VERSION ""
#define SWOOLE_VERSION "4.11.1"
#define SWOOLE_VERSION_ID 41101
#define SWOOLE_API_VERSION_ID 0x202012a

#define SWOOLE_BUG_REPORT                                                                                              \
    "A bug occurred in OpenSwoole-v" SWOOLE_VERSION ", please report it.\n"                                            \
    "Please submit bug report at:\n"                                                                                   \
    ">> https://github.com/openswoole/swoole-src/issues \n"
#endif
